==> haskell-primitive-0.9.1.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
key:                  primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  3867da70aa6ae56e79c5cc1f50beaed7
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
include-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.9.1.0-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-IYGvfPhp8bDLAkMykHY1iR
key:                  primitive-0.9.1.0-IYGvfPhp8bDLAkMykHY1iR
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  5be0d84a7282e37323f3a1b5caabd95f
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-IYGvfPhp8bDLAkMykHY1iR
include-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
